#!/bin/sh

. /etc.defaults/rc.subr

#synorcd=/usr/syno/sbin/synorcd
PACKAGE_DIR="/var/packages/AudioStation"
PACKAGE_TARGET_DIR="${PACKAGE_DIR}/target"
synoaudiod="${PACKAGE_TARGET_DIR}/sbin/synoaudiod"
pulseaudio="${PACKAGE_TARGET_DIR}/bin/pulseaudio"
usbfunc="${PACKAGE_TARGET_DIR}/scripts/usb.function"
SZF_PROG_BLUETOOTHD="/usr/syno/sbin/bluetoothd"
CAT=/bin/cat
RENICE=/usr/bin/renice
SZF_AUDIOD_PID=/var/run/synoaudiod.pid
#dms_local="/usr/syno/sbin/dms.local --localserver"
KERNELMODULE="soundcore snd-page-alloc snd snd-seq-device snd-rawmidi snd-usbmidi-lib snd-usb-lib snd-hwdep snd-timer snd-pcm snd-usb-audio snd-mixer-oss snd-pcm-oss"
UPGRADE_SCRIPTS_DIR="${PACKAGE_TARGET_DIR}/scripts/upgrade/"
MTPLAYLIST="/etc/mt-daapd.playlist"

IsBlueToothSupport()
{
	if [ -f "${SZF_PROG_BLUETOOTHD}" ]; then
		true
		return
	fi
	false
}

CheckIfDaemonAlive()
{
	if [ -f "$1" ]; then
		local processPid=`cat $1`
		kill -0 ${processPid} > /dev/null 2>&1
		if [ "0" = "$?" ]; then
			true
			return
		fi
	fi
	false
}

case $1 in
	start)
		if [ ! -f "${MTPLAYLIST}" ]; then
			touch ${MTPLAYLIST}
		fi

		upgrades=`find $UPGRADE_SCRIPTS_DIR -name "*.sh" | sort`
		for ThisArg in $upgrades;
		do
			$ThisArg
		done

		if CheckIfDaemonAlive "$SZF_AUDIOD_PID"; then
			echo "Daemon synoaudiod exist. Skip start action."
		else
			echo "Starting synoaudiod ..."
			SYNOLoadModules $KERNELMODULE
			$synoaudiod

			if IsBlueToothSupport; then
				echo "Starting pulseaudio"
				$pulseaudio
				`${usbfunc} rescan`
			fi

			# renice audiod to higher priority
			sleep 1
			$RENICE -5 `$CAT $SZF_AUDIOD_PID`
		fi
	;;
	stop)
		echo "Stopping synoaudiod ..."
		/usr/bin/killall synoaudiod > /dev/null 2>&1
		sleep 1
		/usr/bin/killall -9 synoaudiod > /dev/null 2>&1
		SYNOUnloadModules $KERNELMODULE
		rm -f $SZF_AUDIOD_PID

		if IsBlueToothSupport; then
			echo "Stopping pulseaudio"
			/usr/bin/killall pulseaudio > /dev/null 2>&1
		fi
	;;
	restart)
		$0 stop
		sleep 1
		$0 start
	;;
	*)
		echo "Usage: $0 start|stop|restart"
	;;
esac

