BEGIN;

CREATE TABLE personal_music
(
  userid int4 NOT NULL,
  id serial NOT NULL,
  path text NOT NULL,
  title text NOT NULL,
  filesize int8 NOT NULL DEFAULT 0,
  album text,
  artist text,
  album_artist text,
  composer text,
  comment text,
  year int4,
  genre varchar(128),
  frequency int4,
  bitrate int4,
  duration int4,
  channel int4,
  track int4,
  disc int4,
  covercount int4,
  date timestamp,
  mdate timestamp,
  fs_uuid text,
  fs_online boolean DEFAULT TRUE,
  updated character DEFAULT '1',
  CONSTRAINT personal_music_pkey PRIMARY KEY (id)
)
WITHOUT OIDS;
CREATE INDEX personal_music_album_idx ON personal_music USING btree (album);
CREATE INDEX personal_music_artist_idx ON personal_music USING btree (artist);
CREATE INDEX personal_music_album_artist_idx ON personal_music USING btree (album_artist);
CREATE INDEX personal_music_year_idx ON personal_music USING btree ("year" int4_ops);
CREATE INDEX personal_music_disc_idx ON personal_music USING btree (disc int4_ops);
CREATE INDEX personal_music_track_idx ON personal_music USING btree (track int4_ops);
CREATE INDEX personal_music_genre_idx ON personal_music USING btree (genre);
CREATE INDEX personal_music_composer_idx ON personal_music USING btree (composer);
CREATE INDEX personal_music_title_idx ON personal_music USING btree (title);
CREATE INDEX personal_music_date_idx ON personal_music USING btree (date);
CREATE INDEX personal_music_mdate_idx ON personal_music USING btree (mdate);
CREATE UNIQUE INDEX personal_music_path_idx ON personal_music USING btree (path);

CREATE TABLE personal_playlist
(
  userid int4 NOT NULL,
  id serial NOT NULL,
  path text NOT NULL,
  title text NOT NULL,
  filesize int8 NOT NULL DEFAULT 0,
  album text,
  song_count int4 NOT NULL DEFAULT 0,
  date timestamp,
  mdate timestamp,
  fs_uuid text,
  fs_online boolean DEFAULT TRUE,
  updated character DEFAULT '1',
  CONSTRAINT personal_playlist_pkey PRIMARY KEY (id)
)
WITHOUT OIDS;
CREATE UNIQUE INDEX personal_playlist_path_idx ON personal_playlist USING btree (path);

CREATE TABLE personal_directory
(
  userid int4 NOT NULL,
  id serial NOT NULL,
  path text NOT NULL,
  title text,
  date timestamp,
  mdate timestamp,
  fs_uuid text,
  fs_online boolean DEFAULT TRUE,
  updated character DEFAULT '1',
  CONSTRAINT personal_directory_pkey PRIMARY KEY (id),
  CONSTRAINT personal_directory_path_key UNIQUE (path)
)
WITHOUT OIDS;
CREATE UNIQUE INDEX personal_directory_path_idx ON personal_directory USING btree (path);

COMMIT;
