#!/bin/sh

if [ -z "$SYNOPKG_PKGNAME" ]; then
	PACKAGE_NAME="AudioStation"
else
	PACKAGE_NAME=$SYNOPKG_PKGNAME
fi

SYNO_VERSION_CONF="/etc.defaults/VERSION"

AUDIO_PACKAGE_FOLDER="/var/packages/${PACKAGE_NAME}"
AUDIO_CONF_FOLDER="${AUDIO_PACKAGE_FOLDER}/etc"
AUDIO_CONF="${AUDIO_CONF_FOLDER}/audio.conf"

MIN_PERSONAL_LIBRARY_SUPPORT_VERSION="4.1-2535"
INDEX_PACKAGE_PATH=/usr/syno/etc/synoindex/packages/${PACKAGE_NAME}

PSQL="/usr/syno/pgsql/bin/psql"
DATABASE="mediaserver"
SQL="${AUDIO_PACKAGE_FOLDER}/target/scripts/upgrade/001_create_personal_library_table.pgsql"

SetSupportPersonalLibrary()
{
	key="personal_library_indexable"
	value=$1
	lineInConf=`grep "^$key=" "$AUDIO_CONF"`

	if [ -n "$lineInConf" ]; then
		# dst already has these keys, delete first
		sed -i '/^'$key'=/d' "$AUDIO_CONF"
	fi

	# copy keys from src to dst
	echo "$key=\"$value\"" >> "$AUDIO_CONF"
}

ExecSqlCommand()
{
	$PSQL -U admin $DATABASE -c "$1" > /dev/null 2>&1
}

#test whether dsm version support personal library or not
local majorversion=`grep -s ^majorversion ${SYNO_VERSION_CONF} | head -1 | awk -F \" '{print $2}' | sed 's/ //g'`
local minorversion=`grep -s ^minorversion ${SYNO_VERSION_CONF} | head -1 | awk -F \" '{print $2}' | sed 's/ //g'`
local buildnumber=`grep -s ^buildnumber ${SYNO_VERSION_CONF} | head -1 | awk -F \" '{print $2}' | sed 's/ //g'`
local dsmversion="$majorversion.$minorversion-$buildnumber"

if [ $dsmversion \< $MIN_PERSONAL_LIBRARY_SUPPORT_VERSION ]; then
	#dsm not support personal library
	SetSupportPersonalLibrary "no"
	return 0
else
	#dsm support personal library
	SetSupportPersonalLibrary "yes"
fi

echo "Test whether personal library tables exist or not"
ExecSqlCommand "SELECT 1 FROM personal_music LIMIT 1;"
no_table=$?
if [ $no_table = 1 ]; then
	#create personal library tables
	echo "Create personal library tables in $DATABASE db"
	$PSQL -U admin $DATABASE < $SQL
	if [ $? != 0 ]; then
		echo "Failed to create personal library tables in $DATABASE db"
		exit 1;
	fi
fi

/usr/syno/etc.defaults/rc.d/S66synoindexd.sh stop
/usr/syno/etc.defaults/rc.d/S77synomkthumbd.sh stop
/usr/syno/etc.defaults/rc.d/S88synomkflvd.sh stop

cp -rf ${AUDIO_PACKAGE_FOLDER}/target/etc/index/libaudioindex.so ${INDEX_PACKAGE_PATH}

/usr/syno/etc.defaults/rc.d/S66synoindexd.sh start
/usr/syno/etc.defaults/rc.d/S77synomkthumbd.sh start
/usr/syno/etc.defaults/rc.d/S88synomkflvd.sh start

if [ $no_table = 1 ]; then
	#reindex personal library
	if [ -f $AUDIO_CONF ]; then
		grep "enable_personal_library=\"yes\"" $AUDIO_CONF > /dev/null 2>&1
		if [ $? = 0 ]; then
			echo "Re-index personal library"
			for PATH in `find /var/services/homes/*/music -maxdepth 0`
			do
				/usr/syno/bin/synoindex -R "$PATH"
			done
		fi
	fi
fi

exit 0;
